<?php
/**
*
* @package phpBB Extension - Fixed Header and Footer Navbar
* @copyright (c) 2017 Stoker
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\fixedheaderfooter\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{

	/** @var \phpbb\request\request */
	protected $request;
	
	/* @var \phpbb\template\template */
	protected $template;

	/* @var \phpbb\user */
	protected $user;

	/**
	* Constructor
	*
	* @param \phpbb\config\config        $config             Config object
	* @param \phpbb\template\template    $template           Template object
	* @return \stoker\fixedheaderfooter\event\listener
	* @access public
	*/
	public function __construct(\phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
	{
		$this->request = $request;
		$this->template = $template;
		$this->user = $user;
	}


	/**
	* Assign functions defined in this class to event listeners in the core
	*
	* @return array
	* @static
	* @access public
	*/
	static public function getSubscribedEvents()
	{
		return array(
			'core.page_header'						=> 'main',
			'core.ucp_prefs_personal_data'			=> 'ucp_prefs_get_data',
			'core.ucp_prefs_personal_update_data'	=> 'ucp_prefs_set_data',
		);
	}
	
	public function main($event)
	{
		$this->template->assign_vars(array(
			'S_FIXEDHEADERFOOTERHEADER'		=>	!empty($this->user->data['user_fixedheaderfooterheader']) ? true : false,
			'S_FIXEDHEADERFOOTERFOOTER'		=>	!empty($this->user->data['user_fixedheaderfooterfooter']) ? true : false,
		));
	}
	
	/**
	* Get user's option and display it in UCP Prefs View page
	*
	* @param object $event The event object
	* @return null
	* @access public
	*/
	public function ucp_prefs_get_data($event)
	{
		// Request the user option vars and add them to the data array
		$event['data'] = array_merge($event['data'], array(
			'fixedheaderfooterheader'			=> $this->request->variable('fixedheaderfooterheader', (int) $this->user->data['user_fixedheaderfooterheader']),
			'fixedheaderfooterfooter'			=> $this->request->variable('fixedheaderfooterfooter', (int) $this->user->data['user_fixedheaderfooterfooter']),
		));

		// Output the data vars to the template (except on form submit)
		if (!$event['submit'])
		{
			$this->user->add_lang_ext('stoker/fixedheaderfooter', 'fixedheaderfooter_ucp');
			$this->template->assign_vars(array(
				'S_UCP_FIXEDHEADERFOOTERHEADER'		=> $event['data']['fixedheaderfooterheader'],
				'S_UCP_FIXEDHEADERFOOTERFOOTER'		=> $event['data']['fixedheaderfooterfooter'],
			));
		}
	}

	/**
	* Add user's welcome option state into the sql_array
	*
	* @param object $event The event object
	* @return null
	* @access public
	*/
	public function ucp_prefs_set_data($event)
	{
		$event['sql_ary'] = array_merge($event['sql_ary'], array(
			'user_fixedheaderfooterheader' => $event['data']['fixedheaderfooterheader'],
			'user_fixedheaderfooterfooter' => $event['data']['fixedheaderfooterfooter'],
		));
	}
}